.. _aiomsa-e2ap:

======
Models
======

.. currentmodule:: aiomsa.abc

The following models are a variety of :class:`~.enum.IntEnum` and
:func:`~.dataclasses.dataclass` objects used by the :class:`~.E2Client`.

.. autoclass:: RICActionType
.. autoclass:: RICControlAckRequest
.. autoclass:: RICSubsequentActionType
.. autoclass:: RICTimeToWait

.. autoclass:: E2Cell
.. autoclass:: E2Node
.. autoclass:: ServiceModel
.. autoclass:: RanFunction
.. autoclass:: ReportStyle
.. autoclass:: RICAction
.. autoclass:: RICSubsequentAction
